@@ -24,7 +24,7 @@
 
 namespace ayaji {
 	class OPTree;
-	typedef int Label;
+	using Label = int;
 	typedef std::vector<Label> LabelSeq;
 
 	class Node : public std::enable_shared_from_this<Node> {
